@@ -186,6 +186,16 @@ class cqHttpApi(asyncHttp):
             "messages": message,
         }
         self.add("/send_group_forward_msg", post_data)
+    
+    def send_private_forward_msg(self, user_id, message):
+        """
+        发送合并转发 ( 私聊 )
+        """
+        post_data = {
+            "user_id":user_id,
+            "messages": message,
+        }
+        self.add("/send_private_forward_msg", post_data)
 
     def send_reply(self, from_message, message, auto_escape=False):
         """
@@ -215,7 +225,7 @@ class cqHttpApi(asyncHttp):
             "user_id":user_id,
             "duration":int(duration) * 60
         }
-        self.add("/send_msg", post_data)
+        self.add("/set_group_ban", post_data)
     
     def set_group_whole_ban(self, group_id, enable=True):
         """
@@ -225,7 +235,7 @@ class cqHttpApi(asyncHttp):
             "group_id":group_id,
             "enable": enable
         }
-        self.add("/send_msg", post_data)
+        self.add("/set_group_whole_ban", post_data)
     
     def set_group_admin(self, group_id, user_id, enable=True):
         """
@@ -236,7 +246,7 @@ class cqHttpApi(asyncHttp):
             "user_id": user_id,
             "enable": enable
         }
-        self.add("/send_msg", post_data)
+        self.add("/set_group_admin", post_data)
     
     def set_group_card(self, group_id, user_id, card=""):
         """
@@ -247,7 +257,7 @@ class cqHttpApi(asyncHttp):
             "user_id": user_id,
             "card": card
         }
-        self.add("/send_msg", post_data)
+        self.add("/set_group_card", post_data)
     
     def set_group_name(self, group_id, group_name):
         """
@@ -257,7 +267,7 @@ class cqHttpApi(asyncHttp):
             "group_id":group_id,
             "group_name": group_name,
         }
-        self.add("/send_msg", post_data)
+        self.add("/set_group_name", post_data)
 
     def set_group_leave(self, group_id, is_dismiss=False):
         """
@@ -267,7 +277,7 @@ class cqHttpApi(asyncHttp):
             "group_id":group_id,
             "is_dismiss": is_dismiss,
         }
-        self.add("/send_msg", post_data)
+        self.add("/set_group_leave", post_data)
     
     def set_group_special_title(self, group_id, user_id, special_title="", duration=-1):
         """
@@ -279,7 +289,7 @@ class cqHttpApi(asyncHttp):
             "special_title": special_title,
             "duration": duration
         }
-        self.add("/send_msg", post_data)
+        self.add("/set_group_special_title", post_data)
 
     def set_friend_add_request(self, flag, approve, remark):
         """
@@ -290,7 +300,7 @@ class cqHttpApi(asyncHttp):
             "approve": approve,
             "remark": remark,
         }
-        self.add("/send_msg", post_data)
+        self.add("/set_friend_add_request", post_data)
     
     def set_group_add_request(self, flag, sub_type, approve=True, reason=""):
         """
@@ -302,7 +312,7 @@ class cqHttpApi(asyncHttp):
             "sub_type": sub_type,
             "reason": reason
         }
-        self.add("/send_msg", post_data)
+        self.add("/set_group_add_request", post_data)
     
     def get_msg(self, message_id):
         """
@@ -350,6 +360,15 @@ class cqHttpApi(asyncHttp):
         }
         return self._link("/get_image", post_data)
     
+    def delete_msg(self, message_id):
+        """
+        撤回消息
+        """
+        post_data = {
+            "message_id": message_id
+        }
+        self.add("/delete_msg", post_data)
+    
     async def _cqhttp_download_file(self, url, headers):
         """
         go-cqhttp 的内置下载 (异步)
@@ -378,6 +397,21 @@ class cqHttpApi(asyncHttp):
         """
         return self._link("/get_status")
     
+    def upload_group_file(self, group_id, file, name, folder=None):
+        """
+        上传群文件
+        """
+        post_data = {
+            "group_id": group_id,
+            "file": "file://%s" % file,
+            "name": name
+        }
+
+        if folder is not None:
+            post_data["folder"] = folder
+
+        self.add("/upload_group_file", post_data)
+    
     def recordMessageInvalid(self, record_message_data, sql_link):
         """
         长效消息存储 消息失效
@@ -411,7 +445,7 @@ class cqBot(cqSocket, cqEvent):
     cqBot 机器人
     """
 
-    def __init__(self, cqapi, host, group_id_list=[], user_id_list=[], options={}):
+    def __init__(self, cqapi: cqHttpApi, host: str, group_id_list: list=[], user_id_list: list=[], options: dict={}):
         super().__init__(host)
 
         self.cqapi = cqapi
@@ -497,8 +531,8 @@ class cqBot(cqSocket, cqEvent):
             ]
         })
 
-    def _on_message(self, wsapp, message):
-        event_name = super()._on_message(wsapp, message)
+    def _on_message(self, message):
+        message, event_name = super()._on_message(message)
         if event_name is None:
             return
 
@@ -518,10 +552,10 @@ class cqBot(cqSocket, cqEvent):
     def _import_plugin(self, plugin: str, plugin_config: dict):
         try:
             if plugin.rsplit(".", maxsplit=1)[0] == "pycqBot.plugin":
-                plugin_obj = importlib.import_module(plugin)
                 plugin = plugin.rsplit(".", maxsplit=1)[-1]
+                plugin_obj = importlib.import_module(f"pycqBot.plugin.{plugin}.{plugin}")
             else:
-                plugin_obj = importlib.import_module("plugin.%s" % plugin)
+                plugin_obj = importlib.import_module("plugin.%s.%s" % plugin)
 
             if eval("plugin_obj.%s.__base__.__name__ != 'Plugin'" % plugin):
                 logging.warning("%s 插件未继承 pycqBot.Plugin 不进行加载" % plugin)
@@ -825,6 +859,14 @@ class cqBot(cqSocket, cqEvent):
             self.cqapi._reply_add(message.user_id, message)
         
         return message
+    
+    def _message_run(self, message, message_type) -> Message:
+        message = self._message(message)
+        self._plugin_event_run(f"on_{message_type}_msg", message)
+        self._run_command(message, message_type)
+
+        return message
+
 
     def _message_private(self, message) -> Message:
         """
@@ -833,10 +875,8 @@ class cqBot(cqSocket, cqEvent):
         if (message["user_id"] not in self.__user_id_list) and self.__user_id_list != []:
             return
 
-        message = self._message(message)
+        message = self._message_run(message, "private")
         self.on_private_msg(message)
-        self._plugin_event_run("on_private_msg", message)
-        self._run_command(message, "private")
 
         return message
     
@@ -847,9 +887,8 @@ class cqBot(cqSocket, cqEvent):
         if message["group_id"] not in self.__group_id_list and self.__group_id_list != []:
             return
 
-        message = self._message(message)
+        message = self._message_run(message, "group")
         self.on_group_msg(message)
-        self._plugin_event_run("on_group_msg", message)
 
         for cqCode in message.code:
             if cqCode["type"] == "at":
@@ -860,8 +899,6 @@ class cqBot(cqSocket, cqEvent):
                 
                 self.at(message, message.code, cqCode)
                 self._plugin_event_run("at", message, message.code, cqCode)
-        
-        self._run_command(message, "group")
 
         return message
     
@@ -886,6 +923,27 @@ class cqBot(cqSocket, cqEvent):
         群临时会话私聊消息
         """
         self._message_private(message)
+
+    def message_sent_private_friend(self, message):
+        """
+        自身消息私聊上报
+        """
+        self._message_private(message)
+
+    def message_group_anonymous(self, message):
+        """
+        群匿名消息
+        """
+        self._message_group(message)
+    
+    def message_private_group_self(self, message):
+        """
+        群中自身消息上报
+        """
+        self._message_group(message)
+
+    def message_sent_group_normal(self, message):
+        self._message_group(message)
     
     def message_private_group_self(self, message):
         """
@@ -939,6 +997,25 @@ class cqBot(cqSocket, cqEvent):
         """
         self._bot_message_log("指令 %s 运行时错误... Error: %s" % (message.text, err), message)
         logging.exception(err)
+    
+    def notice_group_decrease_kick_me(self, message):
+        """
+        群成员减少 - 登录号被踢
+        """
+        if message["group_id"] in self.__group_id_list:
+            self.__group_id_list.remove(message["group_id"])
+
+        async def _notice_group_decrease_kick_me(message):
+            post_data = {
+                "user_id": message["user_id"]
+            }
+            user_data = await self.cqapi._asynclink("/get_stranger_info", post_data)
+            if user_data is None:
+                return
+            
+            logging.info("bot 被 %s (qq=%s) T出群 685735591" % (user_data["data"]["nickname"], user_data["data"]["user_id"]))
+
+        self.cqapi.add_task(_notice_group_decrease_kick_me(message))
 
 
 class cqLog:
