@@ -4,7 +4,8 @@ import platform
 import subprocess
 from threading import Thread
 import time
-import websocket
+from websockets import ConnectionClosed
+import websockets
 import asyncio
 import aiohttp
 import aiofiles
@@ -107,7 +108,11 @@ class cqSocket:
             "message_private_other": self.message_private_other,
             # 群消息
             "message_group_normal": self.message_group_normal,
-            "message_group_anonymous": self.message_group_normal,
+            "message_group_anonymous": self.message_group_anonymous,
+            # 自身群消息上报
+            "message_sent_group_normal": self.message_sent_group_normal,
+            # 自身消息私聊上报
+            "message_sent_private_friend": self.message_sent_private_friend,
             # 群文件上传
             "notice_group_upload": self.notice_group_upload,
             # 群管理员变动
@@ -116,7 +121,7 @@ class cqSocket:
             # 群成员减少
             "notice_group_decrease_leave": self.notice_group_decrease_leave,
             "notice_group_decrease_kick": self.notice_group_decrease_kick,
-            "notice_group_decrease_kickme": self.notice_group_decrease_kickme,
+            "notice_group_decrease_kick_me": self.notice_group_decrease_kick_me,
             # 群成员增加
             "notice_group_increase_approve": self.notice_group_increase_approve,
             "notice_group_increase_invite": self.notice_group_increase_invite,
@@ -167,9 +172,17 @@ class cqSocket:
         if "WARNING" in shell_msg[0]:
             logging.warning("go-cqhttp %s" % shell_msg[-1])
             return
+        
+        if "DEBUG" in shell_msg[0]:
+            logging.debug(shell_msg[-1])
+            return
+        
+        if "ERROR" in shell_msg[0]:
+            logging.error("go-cqhttp 发生错误 %s" % shell_msg[-1])
+            return
 
         if "FATAL" in shell_msg[0]:
-            logging.error("go-cqhttp 发生错误 %s" % shell_msg[-1])
+            logging.error("go-cqhttp 发生致命错误 %s" % shell_msg[-1])
             return
         
         print(shell_msg[-1])
@@ -223,16 +236,23 @@ class cqSocket:
         """
         连接 websocket 会话
         """
-        if self._debug:
-            websocket.enableTrace(True)
+        async def main_logic():
+            logging.info("正在连接 go-cqhttp websocket 服务")
+            while True:
+                try:
+                    # 只接收 event
+                    async with websockets.connect(self._host) as websocket:
+                        while True:
+                            try:
+                                self._on_message(await websocket.recv())
+                            except Exception as err:
+                                self.on_error(err)
+
+                except ConnectionClosed as err:
+                    logging.error("websocket 会话被关闭 %s" % err)
+                    await asyncio.sleep(2)
         
-        wsapp = websocket.WebSocketApp(self._host,
-                on_message=self._on_message, 
-                on_error=self.on_error,
-                on_open=self.on_open,
-            )
-        # 打开连接
-        wsapp.run_forever()
+        asyncio.run(main_logic())
     
     def _set_event_name(self, message):
         """
@@ -253,28 +273,22 @@ class cqSocket:
         return event_name
 
 
-    def _on_message(self, wsapp, message):
+    def _on_message(self, message):
         """
         处理数据不建议修改, 错误修改将导致无法运行
         除非已经了解如何工作
         """
-        data = json.loads(message)
+        message = json.loads(message)
         
-        event_name = self._set_event_name(data)
+        event_name = self._set_event_name(message)
         if event_name in self.__event:
-            self.__event[event_name](data)
+            self.__event[event_name](message)
 
-            return event_name
+            return message, event_name
         else:
             logging.warning("未知数据协议:%s" % event_name)
 
-    def on_open(self, wsapp):
-        """
-        准备打开 websocket 会话
-        """
-        logging.info("正在连接 go-cqhttp websocket 服务")
-
-    def on_error(self, wsapp, error):
+    def on_error(self, error):
         """
         websocket 会话错误
         """
